<h1 align="center">
  Mafia Online API on Python
</h1>


<p align="center">
  <a href="https://discord.gg/AsYzxRfT6J"><img src="https://bit.ly/32neyjM"></a>
</p>


<p align="center">This library for <a href="https://play.google.com/store/apps/details?id=com.tokarev.mafia">Mafia Online</a></p>

# Install
```
git clone https://github.com/Zakovskiy/mafiaonline.py
```

# Import and Auth
```python
import mafiaonline

Mafia = mafiaonline.Client()
Mafia.sign_in("email", "password")
```

### [Telegram](https://t.me/zakovskiy)
